@@ -11,9 +11,12 @@ class rabbitmq_helper():
         self.message_dict = {};
 
     def send_message(self,body,quenuName):
-
-        result = self.channel.queue_declare(queue = quenuName,durable = True)
+        credentials = pika.PlainCredentials(self.user, self.pwd)  # mq用户名和密码
+        connection = pika.BlockingConnection(pika.ConnectionParameters(host = self.host,port = 5672,virtual_host = '/',credentials = credentials,heartbeat=5))
+        self.channel = connection.channel()
+        self.channel.queue_declare(queue = quenuName,durable = True)
         self.channel.basic_publish(exchange = '',routing_key = quenuName,body = body,properties=pika.BasicProperties(delivery_mode = 2))
+        connection.close()
 
     
     def receive_message(self,name):
